@@ -11,6 +11,8 @@ import copy
 from pathlib import Path
 # from multiprocessing import Process
 import datetime
+
+import orjson
 # noinspection PyUnresolvedReferences,PyPackageRequirements
 import pytz
 import json
@@ -27,6 +29,7 @@ from typing import Callable
 from functools import wraps
 import threading
 from threading import Lock, Thread
+import gevent
 import asyncio
 
 from apscheduler.schedulers.background import BackgroundScheduler
@@ -54,6 +57,8 @@ from funboost.concurrent_pool.bounded_threadpoolexcutor import \
 from func_timeout import func_set_timeout  # noqa
 from funboost.concurrent_pool.custom_threadpool_executor import \
     CustomThreadPoolExecutor, check_not_monkey
+from funboost.concurrent_pool.custom_gevent_pool_executor import gevent_timeout_deco, \
+    GeventPoolExecutor, check_gevent_monkey_patch
 # from funboost.concurrent_pool.concurrent_pool_with_multi_process import ConcurrentPoolWithProcess
 from funboost.consumers.redis_filter import RedisFilter, RedisImpermanencyFilter
 from funboost.factories.publisher_factotry import get_publisher
@@ -121,7 +126,7 @@ class FunctionResultStatus(LoggerMixin, LoggerLevelSetterMixin):
             self.publish_time_str = time_util.DatetimeConverter(publish_time).datetime_str
         function_params = _delete_keys_and_return_new_dict(msg_dict, )
         self.params = function_params
-        self.params_str = json.dumps(function_params, ensure_ascii=False)
+        # self.params_str = json.dumps(function_params, ensure_ascii=False)
         self.result = None
         self.run_times = 0
         self.exception = None
@@ -145,7 +150,7 @@ class FunctionResultStatus(LoggerMixin, LoggerLevelSetterMixin):
         # item.pop('time_start')
         datetime_str = time_util.DatetimeConverter().datetime_str
         try:
-            json.dumps(item['result'])  # 不希望存不可json序列化的复杂类型。麻烦。存这种类型的结果是伪需求。
+            orjson.dumps(item['result'])  # 不希望存不可json序列化的复杂类型。麻烦。存这种类型的结果是伪需求。
         except TypeError:
             item['result'] = str(item['result'])[:1000]
         item.update({'insert_time_str': datetime_str,
@@ -165,7 +170,7 @@ class FunctionResultStatus(LoggerMixin, LoggerLevelSetterMixin):
         return item
 
     def __str__(self):
-        return f'''{self.__class__}   {json.dumps(self.get_status_dict(), ensure_ascii=False)}'''
+        return f'''{self.__class__}   {orjson.dumps(self.get_status_dict()).decode()}'''
 
 
 class ResultPersistenceHelper(MongoMixin, LoggerMixin):
@@ -250,6 +255,10 @@ class ConsumersManager:
                 for t in cls.schedulal_thread_to_be_join:
                     # nb_print(t)
                     t.join()
+            elif cls.global_concurrent_mode == ConcurrentModeEnum.GEVENT:
+                # cls.logger.info()
+                # nb_print(cls.schedulal_thread_to_be_join)
+                gevent.joinall(cls.schedulal_thread_to_be_join, raise_error=True, )
 
     @classmethod
     def show_all_consumer_info(cls):
@@ -269,6 +278,8 @@ class ConsumersManager:
             return 'async'
         elif concurrent_mode == ConcurrentModeEnum.SINGLE_THREAD:
             return 'single_thread'
+        elif concurrent_mode == ConcurrentModeEnum.GEVENT:
+            return 'gevent'
         # elif concurrent_mode == ConcurrentModeEnum.LINUX_FORK:
         #     return 'linux_fork'
 
@@ -499,7 +510,7 @@ class AbstractConsumer(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
         filter_class = RedisFilter if task_filtering_expire_seconds == 0 else RedisImpermanencyFilter
         self._redis_filter = filter_class(self._redis_filter_key_name, task_filtering_expire_seconds, self.redis_host)
 
-        self._unit_time_for_count = 10  # 每隔多少秒计数，显示单位时间内执行多少次，暂时固定为10秒。
+        self._unit_time_for_count = 60  # 每隔多少秒计数，显示单位时间内执行多少次，暂时固定为10秒。
         self._execute_task_times_every_unit_time = 0  # 每单位时间执行了多少次任务。
         self._lock_for_count_execute_task_times_every_unit_time = Lock()
         self._current_time_for_execute_task_times_every_unit_time = time.time()
@@ -568,7 +579,10 @@ class AbstractConsumer(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
                 self.logger.warning(f'当前消息队列中间件含有不支持的特殊配置 {self.broker_exclusive_config.keys()}，能支持的特殊独有配置包括 {self.BROKER_EXCLUSIVE_CONFIG_KEYS}')
 
     def _check_monkey_patch(self):
-        check_not_monkey()
+        if self._concurrent_mode == 2:
+            check_gevent_monkey_patch()
+        else:
+            check_not_monkey()
 
     ''' 日志跳转代码行不正确，不用这种方式'''
 
@@ -672,8 +686,8 @@ class AbstractConsumer(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
     def _print_message_get_from_broker(self, broker_name, msg):
         # print(999)
         if self._is_show_message_get_from_broker:
-            if isinstance(msg, (dict, list)):
-                msg = json.dumps(msg, ensure_ascii=False)
+            # if isinstance(msg, (dict, list)):
+            #     msg = json.dumps(msg, ensure_ascii=False)
             self.logger.debug(f'从 {broker_name} 中间件 的 {self._queue_name} 中取出的消息是 {msg}')
 
     def _get_priority_conf(self, kw: dict, broker_task_config_key: str):
@@ -738,7 +752,7 @@ class AbstractConsumer(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
                         # RedisMixin().redis_db_frame.lpush(kw['body']['extra']['task_id'], json.dumps(function_result_status.get_status_dict(without_datetime_obj=True)))
                         # RedisMixin().redis_db_frame.expire(kw['body']['extra']['task_id'], 600)
                         p.lpush(kw['body']['extra']['task_id'],
-                                json.dumps(current_function_result_status.get_status_dict(without_datetime_obj=True)))
+                                orjson.dumps(current_function_result_status.get_status_dict(without_datetime_obj=True)))
                         p.expire(kw['body']['extra']['task_id'], 600)
                         p.execute()
 
@@ -786,11 +800,17 @@ class AbstractConsumer(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
 
                 os._exit(4)
             function_result_status.success = True
+            cost_time = round(time.time() - t_start, 4)
             if self._log_level <= logging.DEBUG:
                 result_str_to_be_print = str(function_result_status.result)[:100] if len(str(function_result_status.result)) < 100 else str(function_result_status.result)[:100] + '  。。。。。  '
                 self.logger.debug(f' 函数 {self.consuming_function.__name__}  '
-                                  f'第{current_retry_times + 1}次 运行, 正确了，函数运行时间是 {round(time.time() - t_start, 4)} 秒,入参是 {function_only_params}  '
+                                  f'第{current_retry_times + 1}次 运行, 正确了，函数运行时间是 {cost_time} 秒,入参是 {function_only_params}  '
                                   f' 结果是  {result_str_to_be_print} ，  {self._get_concurrent_info()}  ')
+            if cost_time > 2:
+                result_str_to_be_print = str(function_result_status.result)[:100] if len(str(function_result_status.result)) < 100 else str(function_result_status.result)[:100] + '  。。。。。  '
+                self.logger.info(f' 函数 {self.consuming_function.__name__}  '
+                                  f'第{current_retry_times + 1}次 运行时间过久， {cost_time} 秒,入参是 {function_only_params}  '
+                                  f' 结果是  {result_str_to_be_print}')
         except BaseException as e:
             if isinstance(e, (ExceptionForRequeue,)):  # mongo经常维护备份时候插入不了或挂了，或者自己主动抛出一个ExceptionForRequeue类型的错误会重新入队，不受指定重试次数逇约束。
                 log_msg = f'函数 [{self.consuming_function.__name__}] 中发生错误 {type(e)}  {e} 。消息重新放入当前队列 {self._queue_name}'
@@ -859,7 +879,7 @@ class AbstractConsumer(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
                 def push_result():
                     with RedisMixin(self.redis_host).redis_db_filter_and_rpc_result.pipeline() as p:
                         p.lpush(kw['body']['extra']['task_id'],
-                                json.dumps(current_function_result_status.get_status_dict(without_datetime_obj=True)))
+                                orjson.dumps(current_function_result_status.get_status_dict(without_datetime_obj=True)))
                         p.expire(kw['body']['extra']['task_id'], 600)
                         p.execute()
 
@@ -1029,7 +1049,7 @@ class AbstractConsumer(LoggerLevelSetterMixin, metaclass=abc.ABCMeta, ):
         publish_time = _get_publish_time(kw['body'])
         msg_expire_senconds_priority = self._get_priority_conf(kw, 'msg_expire_senconds')
         dis = round(time.time() - publish_time, 4)
-        if msg_expire_senconds_priority and dis > 5:
+        if msg_expire_senconds_priority and dis > 20:
             self.alert.info(f'延时报警：{self.queue_name} 消息发布时间距离现在 {dis} 秒,请检查服务器状态')
         if msg_expire_senconds_priority and dis > msg_expire_senconds_priority:
             self.logger.warning(
@@ -1141,10 +1161,10 @@ class ConcurrentModeDispatcher(LoggerMixin):
         self._concurrent_mode = self.consumer._concurrent_mode
         self.timeout_deco = None
         if self._concurrent_mode in (ConcurrentModeEnum.THREADING, ConcurrentModeEnum.SINGLE_THREAD):
-            self.timeout_deco = decorators.timeout
-
             # self.timeout_deco = decorators.timeout
             self.timeout_deco = func_set_timeout  # 这个超时装饰器性能好很多。
+        elif self._concurrent_mode == ConcurrentModeEnum.GEVENT:
+            self.timeout_deco = gevent_timeout_deco
 
         self.logger.warning(f'{self.consumer} 设置并发模式'
                             f'为{ConsumersManager.get_concurrent_name_by_concurrent_mode(self._concurrent_mode)}')
@@ -1172,6 +1192,8 @@ class ConcurrentModeDispatcher(LoggerMixin):
         if self._concurrent_mode == ConcurrentModeEnum.THREADING:
             pool_type = CustomThreadPoolExecutor
             # pool_type = BoundedThreadPoolExecutor
+        elif self._concurrent_mode == ConcurrentModeEnum.GEVENT:
+            pool_type = GeventPoolExecutor
         elif self._concurrent_mode == ConcurrentModeEnum.ASYNC:
             pool_type = AsyncPoolExecutor
         elif self._concurrent_mode == ConcurrentModeEnum.SINGLE_THREAD:
@@ -1201,6 +1223,9 @@ class ConcurrentModeDispatcher(LoggerMixin):
             t = Thread(target=self.consumer.keep_circulating(1)(self.consumer._shedual_task))
             ConsumersManager.schedulal_thread_to_be_join.append(t)
             t.start()
+        elif self._concurrent_mode == ConcurrentModeEnum.GEVENT:
+            g = gevent.spawn(self.consumer.keep_circulating(1)(self.consumer._shedual_task), )
+            ConsumersManager.schedulal_thread_to_be_join.append(g)
 
 
 def wait_for_possible_has_finish_all_tasks_by_conusmer_list(consumer_list: typing.List[AbstractConsumer], minutes: int = 3):
@@ -1260,7 +1285,7 @@ class DistributedConsumerStatistics(RedisMixin, LoggerMixinDefaultWithFileHandle
         results = self.redis_db_frame.smembers(redis_key)
         with self.redis_db_frame.pipeline() as p:
             for result in results:
-                result_dict = json.loads(result)
+                result_dict = orjson.loads(result)
                 if self.timestamp() - result_dict['hearbeat_timestamp'] > 15 \
                         or self._consumer_identification_map['consumer_uuid'] == result_dict['consumer_uuid']:
                     # 因为这个是10秒钟运行一次，15秒还没更新，那肯定是掉线了。如果消费者本身是自己也先删除。
@@ -1290,7 +1315,7 @@ class DistributedConsumerStatistics(RedisMixin, LoggerMixinDefaultWithFileHandle
     def _show_active_consumer_num(self):
         self.active_consumer_num = self.redis_db_frame.scard(self._redis_key_name) or 1
         if time.time() - self._last_show_consumer_num_timestamp > 600:
-            self.logger.info(f'分布式所有环境中使用 {self._queue_name} 队列的，一共有 {self.active_consumer_num} 个消费者')
+            self.logger.debug(f'分布式所有环境中使用 {self._queue_name} 队列的，一共有 {self.active_consumer_num} 个消费者')
             self._last_show_consumer_num_timestamp = time.time()
 
     def get_queue_heartbeat_ids(self, without_time: bool):
@@ -1330,7 +1355,7 @@ class ActiveCousumerProcessInfoGetter(RedisMixin, LoggerMixinDefaultWithFileHand
         # 如果所有机器所有进程都全部关掉了，就没办法还剩一个线程执行删除了，这里还需要判断一次15秒。
         active_consumers_processor_info_list = []
         for result in results:
-            result_dict = json.loads(result)
+            result_dict = orjson.loads(result)
             if self.timestamp() - result_dict['hearbeat_timestamp'] < 15:
                 active_consumers_processor_info_list.append(result_dict)
         return active_consumers_processor_info_list
@@ -1375,7 +1400,7 @@ class ActiveCousumerProcessInfoGetter(RedisMixin, LoggerMixinDefaultWithFileHand
             dict_key = key.replace(redis_key_prefix, '')
             infos_map[dict_key] = []
             for info_str in infos:
-                info_dict = json.loads(info_str)
+                info_dict = orjson.loads(info_str)
                 if self.timestamp() - info_dict['hearbeat_timestamp'] < 15:
                     infos_map[dict_key].append(info_dict)
         return infos_map
