@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
 # @Author  : ydf
 # @Time    : 2022/8/8 0008 13:32
-import json
+
+import orjson
 # noinspection PyPackageRequirements
 from kafka import KafkaConsumer as OfficialKafkaConsumer, KafkaProducer, KafkaAdminClient
 # noinspection PyPackageRequirements
@@ -14,7 +15,7 @@ from funboost import funboost_config_deafult
 from ga_log import get_logger, LogManager
 
 # LogManager('kafka').get_logger_and_add_handlers(30)
-get_logger('kafka', log_level_int=20)
+get_logger('kafka', log_level_int=30)
 
 
 class KafkaConsumer(AbstractConsumer):
@@ -29,6 +30,13 @@ class KafkaConsumer(AbstractConsumer):
 
     BROKER_EXCLUSIVE_CONFIG_KEYS = ['group_id','auto_offset_reset']
     # not_all_brokers_general_settings配置 ，支持独立的中间件配置参数是 group_id 和 auto_offset_reset
+    """
+    auto_offset_reset 介绍
+      auto_offset_reset (str): A policy for resetting offsets on
+            OffsetOutOfRange errors: 'earliest' will move to the oldest
+            available message, 'latest' will move to the most recent. Any
+            other value will raise the exception. Default: 'latest'.
+    """
 
     def _shedual_task(self):
         try:
@@ -59,11 +67,11 @@ class KafkaConsumer(AbstractConsumer):
             if self._is_show_message_get_from_broker:
                 self.logger.debug(
                     f'从kafka的 [{message.topic}] 主题,分区 {message.partition} 中 取出的消息是：  {message.value.decode()}')
-            kw = {'consumer': consumer, 'message': message, 'body': json.loads(message.value)}
+            kw = {'consumer': consumer, 'message': message, 'body': orjson.loads(message.value)}
             self._submit_task(kw)
 
     def _confirm_consume(self, kw):
         pass  # 使用kafka的自动commit模式。
 
     def _requeue(self, kw):
-        self._producer.send(self._queue_name, json.dumps(kw['body']).encode())
+        self._producer.send(self._queue_name, orjson.dumps(kw['body'], option=orjson.OPT_NON_STR_KEYS))
