@@ -4,6 +4,8 @@
 import json
 from queue import Queue
 
+import orjson
+
 from funboost.consumers.base_consumer import AbstractConsumer
 from funboost.publishers import local_python_queue_publisher
 
@@ -21,8 +23,8 @@ class LocalPythonQueueConsumer(AbstractConsumer):
     def _shedual_task(self):
         while True:
             task = self.local_python_queue.get()
-            if isinstance(task, str):
-                task = json.loads(task)
+            if isinstance(task, (str, bytes)):
+                task = orjson.loads(task)
             self._print_message_get_from_broker('当前python解释器内部', task)
             # self.logger.debug(f'从当前python解释器内部的 [{self._queue_name}] 队列中 取出的消息是：  {json.dumps(task)}  ')
             kw = {'body': task}
