@@ -4,7 +4,7 @@
 import copy
 from typing import Callable
 from funboost.publishers.base_publisher import AbstractPublisher
-from funboost.publishers.confluent_kafka_publisher import ConfluentKafkaPublisher
+# from funboost.publishers.confluent_kafka_publisher import ConfluentKafkaPublisher
 from funboost.publishers.http_publisher import HTTPPublisher
 # from funboost.publishers.kombu_publisher import KombuPublisher
 # from funboost.publishers.nats_publisher import NatsPublisher
@@ -14,14 +14,14 @@ from funboost.publishers.tcp_publisher import TCPPublisher
 # from funboost.publishers.txt_file_publisher import TxtFilePublisher
 from funboost.publishers.udp_publisher import UDPPublisher
 # from funboost.publishers.zeromq_publisher import ZeroMqPublisher
-from funboost.publishers.kafka_publisher import KafkaPublisher
+# from funboost.publishers.kafka_publisher import KafkaPublisher
 from funboost.publishers.local_python_queue_publisher import LocalPythonQueuePublisher
 from funboost.publishers.mongomq_publisher import MongoMqPublisher
 # from funboost.publishers.nsq_publisher import NsqPublisher
 from funboost.publishers.persist_queue_publisher import PersistQueuePublisher
 from funboost.publishers.rabbitmq_amqpstorm_publisher import RabbitmqPublisherUsingAmqpStorm
 from funboost.publishers.rabbitmq_pika_publisher import RabbitmqPublisher
-from funboost.publishers.rabbitmq_rabbitpy_publisher import RabbitmqPublisherUsingRabbitpy
+# from funboost.publishers.rabbitmq_rabbitpy_publisher import RabbitmqPublisherUsingRabbitpy
 from funboost.publishers.redis_publisher import RedisPublisher
 # from funboost.publishers.rocketmq_publisher import RocketmqPublisher
 # from funboost.publishers.sqla_queue_publisher import SqlachemyQueuePublisher
@@ -31,14 +31,14 @@ from funboost.publishers.httpsqs_publisher import HttpsqsPublisher
 
 broker_kind__publisher_type_map = {
     0: RabbitmqPublisherUsingAmqpStorm,
-    1: RabbitmqPublisherUsingRabbitpy,
+    # 1: RabbitmqPublisherUsingRabbitpy,
     2: RedisPublisher,
     3: LocalPythonQueuePublisher,
     4: RabbitmqPublisher,
     5: MongoMqPublisher,
     6: PersistQueuePublisher,
     # 7: NsqPublisher,
-    8: KafkaPublisher,
+    # 8: KafkaPublisher,
     9: RedisPublisher,
     # 10: SqlachemyQueuePublisher,
     # 11: RocketmqPublisher,
@@ -46,7 +46,7 @@ broker_kind__publisher_type_map = {
     # 13: ZeroMqPublisher,
     14: RedisPublisherLpush,
     # 15: KombuPublisher,
-    16: ConfluentKafkaPublisher,
+    # 16: ConfluentKafkaPublisher,
     17: MqttPublisher,
     18: HttpsqsPublisher,
     21: UDPPublisher,
