@@ -3,8 +3,7 @@ import redis2 as redis
 import redis3
 from funboost import funboost_config_deafult
 from funboost.utils import decorators
-
-from aioredis.client import Redis as AioRedis
+from redis import asyncio as aioRedis
 
 
 class RedisManager(object):
@@ -36,54 +35,55 @@ class RedisMixin(object):
     """
     可以被作为万能mixin能被继承，也可以单独实例化使用。
     """
+
     def __init__(self, redis_host=None):
         self.redis_host = redis_host
 
     @property
-    #@decorators.cached_method_result
+    # @decorators.cached_method_result
     def redis_db0(self):
         return RedisManager(host=self.redis_host or funboost_config_deafult.REDIS_HOST, port=funboost_config_deafult.REDIS_PORT,
                             password=funboost_config_deafult.REDIS_PASSWORD, db=0).get_redis()
 
     @property
-    #@decorators.cached_method_result
+    # @decorators.cached_method_result
     def redis_db8(self):
         return RedisManager(host=self.redis_host or funboost_config_deafult.REDIS_HOST, port=funboost_config_deafult.REDIS_PORT,
                             password=funboost_config_deafult.REDIS_PASSWORD, db=8).get_redis()
 
     @property
-    #@decorators.cached_method_result
+    # @decorators.cached_method_result
     def redis_db7(self):
         return RedisManager(host=self.redis_host or funboost_config_deafult.REDIS_HOST, port=funboost_config_deafult.REDIS_PORT,
                             password=funboost_config_deafult.REDIS_PASSWORD, db=7).get_redis()
 
     @property
-    #@decorators.cached_method_result
+    # @decorators.cached_method_result
     def redis_db6(self):
         return RedisManager(host=self.redis_host or funboost_config_deafult.REDIS_HOST, port=funboost_config_deafult.REDIS_PORT,
                             password=funboost_config_deafult.REDIS_PASSWORD, db=6).get_redis()
 
     @property
-    #@decorators.cached_method_result
+    # @decorators.cached_method_result
     def redis_db_frame(self):
         return RedisManager(host=self.redis_host or funboost_config_deafult.REDIS_HOST, port=funboost_config_deafult.REDIS_PORT,
                             password=funboost_config_deafult.REDIS_PASSWORD, db=funboost_config_deafult.REDIS_DB).get_redis()
 
     @property
-    #@decorators.cached_method_result
+    # @decorators.cached_method_result
     def redis_db_frame_version3(self):
         ''' redis 3和2 入参和返回差别很大，都要使用'''
         return redis3.Redis(host=self.redis_host or funboost_config_deafult.REDIS_HOST, port=funboost_config_deafult.REDIS_PORT,
                             password=funboost_config_deafult.REDIS_PASSWORD, db=funboost_config_deafult.REDIS_DB, decode_responses=True)
 
     @property
-    #@decorators.cached_method_result
+    # @decorators.cached_method_result
     def redis_db_filter_and_rpc_result(self):
         return RedisManager(host=self.redis_host or funboost_config_deafult.REDIS_HOST, port=funboost_config_deafult.REDIS_PORT,
                             password=funboost_config_deafult.REDIS_PASSWORD, db=funboost_config_deafult.REDIS_DB_FILTER_AND_RPC_RESULT).get_redis()
 
     @property
-    #@decorators.cached_method_result
+    # @decorators.cached_method_result
     def redis_db_filter_and_rpc_result_version3(self):
         return redis3.Redis(host=self.redis_host or funboost_config_deafult.REDIS_HOST, port=funboost_config_deafult.REDIS_PORT,
                             password=funboost_config_deafult.REDIS_PASSWORD, db=funboost_config_deafult.REDIS_DB_FILTER_AND_RPC_RESULT, decode_responses=True)
@@ -99,5 +99,5 @@ class AioRedisMixin(object):
     @property
     @decorators.cached_method_result
     def aioredis_db_filter_and_rpc_result(self):
-        return AioRedis(host=funboost_config_deafult.REDIS_HOST, port=funboost_config_deafult.REDIS_PORT,
-                        password=funboost_config_deafult.REDIS_PASSWORD, db=funboost_config_deafult.REDIS_DB_FILTER_AND_RPC_RESULT, decode_responses=True)
+        return aioRedis.Redis(host=funboost_config_deafult.REDIS_HOST, port=funboost_config_deafult.REDIS_PORT,
+                              password=funboost_config_deafult.REDIS_PASSWORD, db=funboost_config_deafult.REDIS_DB_FILTER_AND_RPC_RESULT, decode_responses=True)
